@@ -3,9 +3,14 @@ if RUBY_PLATFORM =~ /java/
   require 'do_jdbc'
   require 'java'
 
-  driver = 'org.postgresql.Driver'
+  module DataObjects
+    module Postgres
+      JDBC_DRIVER = 'org.postgresql.Driver'
+    end
+  end
+
   begin
-    java.lang.Thread.currentThread.getContextClassLoader().loadClass(driver, true)
+    java.lang.Thread.currentThread.getContextClassLoader().loadClass(DataObjects::Postgres::JDBC_DRIVER, true)
   rescue
     require 'jdbc/postgres' # the JDBC driver, packaged as a gem
   end
@@ -13,7 +18,7 @@ if RUBY_PLATFORM =~ /java/
   # Another way of loading the JDBC Class. This seems to be more reliable
   # than Class.forName() within the data_objects.Connection Java class,
   # which is currently not working as expected.
-  java_import driver
+  java_import DataObjects::Postgres::JDBC_DRIVER
 
 end
 
